Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(11)

Unified Diff: device/gamepad/gamepad_service.h

Issue 2852803002: Remove base::SharedMemory::ShareToProcess. (Closed)
Patch Set: Compile error. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « device/gamepad/gamepad_provider_unittest.cc ('k') | device/gamepad/gamepad_service.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: device/gamepad/gamepad_service.h
diff --git a/device/gamepad/gamepad_service.h b/device/gamepad/gamepad_service.h
index c5e4aafa0309b46ae02fa2d2ecf6e5d9ccd4b4ad..530178414927dbe39b83f478894d5effc15402b3 100644
--- a/device/gamepad/gamepad_service.h
+++ b/device/gamepad/gamepad_service.h
@@ -67,10 +67,8 @@ class DEVICE_GAMEPAD_EXPORT GamepadService
// while a consumer is active.
void RegisterForUserGesture(const base::Closure& closure);
- // Returns the shared memory handle of the gamepad data duplicated into the
- // given process.
- base::SharedMemoryHandle GetSharedMemoryHandleForProcess(
- base::ProcessHandle handle);
+ // Returns a duplicate of the shared memory handle of the gamepad data.
+ base::SharedMemoryHandle DuplicateSharedMemoryHandle();
// Returns a new mojo::ScopedSharedBuffer handle of the gamepad data.
mojo::ScopedSharedBufferHandle GetSharedBufferHandle();
« no previous file with comments | « device/gamepad/gamepad_provider_unittest.cc ('k') | device/gamepad/gamepad_service.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698